@@ -13,7 +13,7 @@ use Sys::Hostname;
 
 my $MAJOR_VERSION = 1;
 my $MINOR_VERSION = 8;
-my $PATCH_VERSION = 6;
+my $PATCH_VERSION = 9;
 
 my $VERSION_SUFFIX = '';
 
@@ -98,6 +98,12 @@ sub main {
 
     get_options($config);
 
+    unless($$config{'ack_deprecation'}) {
+        croak('configure.pl is no longer supported, exiting. Use option ' .
+              '--i-know-this-is-broken to force build');
+        exit 1;
+    }
+
     my $default_value_is = sub {
         my ($var, $val) = @_;
         $$config{$var} = $val if not defined($$config{$var});
@@ -193,6 +199,10 @@ sub main {
                      File::Spec->catfile($$config{'build_dir'}, 'build.h'),
                      $config);
 
+    process_template(File::Spec->catfile($$config{'config-dir'}, 'innosetup.in'),
+                     File::Spec->catfile($$config{'build_dir'}, 'botan.iss'),
+                     $config) if($os eq 'windows');
+
     process_template(File::Spec->catfile(
                          $$config{'config-dir'}, 'botan.doxy.in'),
                      File::Spec->catfile($$config{'doc_src_dir'}, 'botan.doxy'),
@@ -520,6 +530,7 @@ sub scan_modules {
         next unless(module_runs_on($config, \%modinfo, $mod, 0));
 
         if($modinfo{'load_on'} eq 'auto' or
+           $modinfo{'load_on'} eq 'always' or
             ($modinfo{'load_on'} eq 'asm_ok' and $$config{'asm_ok'})) {
 
             my %maybe_load = ();
@@ -624,6 +635,7 @@ sub get_options {
 
     $$config{'verbose'} = 1;
     $$config{'asm_ok'} = 1;
+    $$config{'ack_deprecation'} = 0;
     $$config{'tr1'} = undef; # not enabled by default
     $$config{'modules'} = {};
 
@@ -741,6 +753,8 @@ sub get_options {
         'quiet' => sub { $$config{'verbose'} = 0; },
         'trace' => sub { $TRACING = 1; },
 
+        'i-know-this-is-broken' => sub { $$config{'ack_deprecation'} = 1 },
+
         'enable-asm' => sub { $$config{'asm_ok'} = 1; },
         'disable-asm' => sub { $$config{'asm_ok'} = 0; },
 
@@ -1581,6 +1595,8 @@ sub read_info_files {
     foreach my $file (dir_list($dir)) {
         my $fullpath = File::Spec->catfile($dir, $file);
 
+        $file =~ s/.txt//;
+
         trace("reading $fullpath");
         %{$allinfo{$file}} = &$func($file, $fullpath);
     }
