@@ -37,7 +37,7 @@ class BuildConfigurationInformation(object):
     """
     version_major = 1
     version_minor = 8
-    version_patch = 6
+    version_patch = 9
     version_so_patch = 2
     version_suffix = ''
 
@@ -164,6 +164,8 @@ def process_command_line(args):
     mods_group.add_option('--disable-modules', dest='disabled_modules',
                           metavar='MODS', action='append', default=[],
                           help='disable specific modules')
+    mods_group.add_option('--no-autoload', action='store_true', default=False,
+                          help='disable automatic loading')
 
     for mod in ['openssl', 'gnump', 'bzip2', 'zlib']:
 
@@ -268,7 +270,7 @@ def lex_me_harder(infofile, to_obj, allowed_groups, name_val_pairs):
         else:
             to_obj.parent_module = None
     else:
-        to_obj.basename = basename
+        to_obj.basename = basename.replace('.txt', '')
 
     lexer = shlex.shlex(open(infofile), infofile, posix=True)
     lexer.wordchars += '|:.<>/,-!' # handle various funky chars in info.txt
@@ -417,7 +419,7 @@ class ArchInfo(object):
         elif self.endian != None:
             macros.append('TARGET_CPU_IS_%s_ENDIAN' % (self.endian.upper()))
 
-        macros.append('TARGET_UNALIGNED_LOADSTORE_OK %d' % (self.unaligned_ok))
+        macros.append('TARGET_UNALIGNED_LOADSTOR_OK %d' % (self.unaligned_ok))
 
         return macros
 
@@ -553,7 +555,7 @@ def canon_processor(archinfo, proc):
     raise Exception('Unknown or unidentifiable processor "%s"' % (proc))
 
 def guess_processor(archinfo):
-    base_proc = platform.machine()
+    base_proc = platform.machine().lower()
 
     if base_proc == '':
         raise Exception('Could not determine target CPU; set with --cpu')
@@ -668,6 +670,11 @@ def create_template_vars(build_config, options, modules, cc, arch, osinfo):
             return os.path.join(options.with_build_dir, path)
         return path
 
+    def only_if_shared(option):
+        if options.build_shared_lib:
+            return option
+        return ''
+
     return {
         'version_major': build_config.version_major,
         'version_minor': build_config.version_minor,
@@ -707,8 +714,8 @@ def create_template_vars(build_config, options, modules, cc, arch, osinfo):
         'check_opt': cc.check_opt_flags,
         'lang_flags': cc.lang_flags + options.extra_flags,
         'warn_flags': cc.warning_flags,
-        'shared_flags': cc.shared_flags,
-        'dll_export_flags': cc.dll_export_flags,
+        'shared_flags': only_if_shared(cc.shared_flags),
+        'dll_import_flags': only_if_shared(cc.dll_import_flags),
 
         'so_link': cc.so_link_command_for(osinfo.basename),
 
@@ -799,10 +806,22 @@ def choose_modules_to_use(options, modules):
                 cannot_use_because(modname, 'loaded on request only')
             elif module.load_on == 'dep':
                 maybe_dep.append(modname)
-            elif module.load_on in ['auto', 'asm_ok']:
-                if module.load_on == 'asm_ok' and not options.asm_ok:
+
+            elif module.load_on == 'always':
+                to_load.append(modname)
+
+            elif module.load_on == 'asm_ok':
+                if options.asm_ok:
+                    if options.no_autoload:
+                        maybe_dep.append(modname)
+                    else:
+                        to_load.append(modname)
+                else:
                     cannot_use_because(modname,
                                        'uses assembly and --disable-asm set')
+            elif module.load_on == 'auto':
+                if options.no_autoload:
+                    maybe_dep.append(modname)
                 else:
                     to_load.append(modname)
             else:
@@ -847,6 +866,8 @@ def choose_modules_to_use(options, modules):
             logging.info('Skipping mod because %s - %s' % (
                 reason, ' '.join(disabled_mods)))
 
+    logging.debug('Loading modules %s', ' '.join(sorted(to_load)))
+
     return [modules[mod] for mod in to_load]
 
 """
@@ -867,18 +888,23 @@ def load_info_files(options):
         for (dirpath, dirnames, filenames) in \
                 os.walk(os.path.join(options.build_data, subdir)):
             for filename in filenames:
-                yield os.path.join(dirpath, filename)
+                if filename.endswith('.txt'):
+                    yield os.path.join(dirpath, filename)
 
-    archinfo = dict([(os.path.basename(info), ArchInfo(info))
+    def form_name(filepath):
+        return os.path.basename(filepath).replace('.txt', '')
+
+    archinfo = dict([(form_name(info), ArchInfo(info))
                      for info in list_files_in_build_data('arch')])
 
-    osinfo   = dict([(os.path.basename(info), OsInfo(info))
+    osinfo   = dict([(form_name(info), OsInfo(info))
                       for info in list_files_in_build_data('os')])
 
-    ccinfo = dict([(os.path.basename(info), CompilerInfo(info))
+    ccinfo = dict([(form_name(info), CompilerInfo(info))
                     for info in list_files_in_build_data('cc')])
 
-    del osinfo['defaults'] # FIXME (remove the file)
+    if 'defaults' in osinfo:
+        del osinfo['defaults'] # FIXME (remove the file)
 
     return (modules, archinfo, ccinfo, osinfo)
 
@@ -951,12 +977,22 @@ def setup_build(build_config, options, template_vars):
         makefile_template: template_vars['makefile_path']
         }
 
-    for (template, sink) in [('buildh.in', 'build.h'),
-                             ('botan-config.in', 'botan-config'),
-                             ('botan.pc.in', build_config.pkg_config_file()),
-                             ('botan.doxy.in', 'botan.doxy')]:
-        templates_to_proc[os.path.join(options.build_data, template)] = \
-             os.path.join(build_config.build_dir, sink)
+    def templates_to_use():
+        yield (options.build_data, 'buildh.in', 'build.h')
+        yield (options.build_data, 'botan.doxy.in', 'botan.doxy')
+
+        if options.os != 'windows':
+            yield (options.build_data, 'botan.pc.in', build_config.pkg_config_file())
+            yield (options.build_data, 'botan-config.in', 'botan-config')
+
+        if options.os == 'windows':
+            yield (options.build_data, 'innosetup.in', 'botan.iss')
+
+    for (template_dir, template, sink) in templates_to_use():
+        source = os.path.join(template_dir, template)
+        if template_dir == options.build_data:
+            sink = os.path.join(build_config.build_dir, sink)
+        templates_to_proc[source] = sink
 
     for (template, sink) in templates_to_proc.items():
         try:
@@ -1002,7 +1038,7 @@ def main(argv = None):
     (modules, archinfo, ccinfo, osinfo) = load_info_files(options)
 
     if options.compiler is None:
-        if platform.system().lower() == 'windows':
+        if options.os == 'windows':
             options.compiler = 'msvc'
         else:
             options.compiler = 'gcc'
