@@ -8,6 +8,7 @@ Written by Jack Lloyd (lloyd@randombit.net), April 7, 2003
 This file is in the public domain
 */
 #include <botan/init.h>
+#include <botan/auto_rng.h>
 #include <botan/x509self.h>
 #include <botan/rsa.h>
 #include <botan/dsa.h>
@@ -15,6 +16,7 @@ using namespace Botan;
 
 #include <iostream>
 #include <fstream>
+#include <memory>
 
 int main(int argc, char* argv[])
    {
@@ -25,16 +27,19 @@ int main(int argc, char* argv[])
       return 1;
       }
 
-   try {
-      LibraryInitializer init;
+   Botan::LibraryInitializer init;
 
-      RSA_PrivateKey priv_key(1024);
+   try
+      {
+      AutoSeeded_RNG rng;
+
+      RSA_PrivateKey priv_key(rng, 1024);
       // If you want a DSA key instead of RSA, comment out the above line and
       // uncomment this one:
       //DSA_PrivateKey priv_key(DL_Group("dsa/jce/1024"));
 
       std::ofstream key_file("private.pem");
-      key_file << PKCS8::PEM_encode(priv_key, argv[1]);
+      key_file << PKCS8::PEM_encode(priv_key, rng, argv[1]);
 
       X509_Cert_Options opts;
 
@@ -54,7 +59,7 @@ int main(int argc, char* argv[])
 
       opts.xmpp = "someid@xmpp.org";
 
-      PKCS10_Request req = X509::create_cert_req(opts, priv_key);
+      PKCS10_Request req = X509::create_cert_req(opts, priv_key, rng);
 
       std::ofstream req_file("req.pem");
       req_file << req.PEM_encode();
